@@ -8,21 +8,27 @@ from cow.plugins.sqlalchemy_plugin import SQLAlchemyPlugin
 from cow.plugins.redis_plugin import RedisPlugin, CowRedisClient
 from tornado.httpclient import AsyncHTTPClient
 #from toredis import Client
+import redis
+from materialgirl import Materializer
+from materialgirl.storage.redis import RedisStorage
 
 from holmes.handlers.worker import WorkerHandler, WorkersHandler, WorkersInfoHandler
 from holmes.handlers.worker_state import WorkerStateHandler
 from holmes.handlers.page import (
-    PageHandler, PageReviewsHandler, PageViolationsPerDayHandler
+    PageHandler, PageReviewsHandler, PageViolationsPerDayHandler, NextJobHandler
 )
 from holmes.handlers.violation import (
-    MostCommonViolationsHandler, ViolationsHandler, ViolationHandler
+    MostCommonViolationsHandler, ViolationsHandler, ViolationHandler, ViolationDomainsHandler
 )
 from holmes.handlers.review import (
     ReviewHandler, LastReviewsHandler
 )
 from holmes.handlers.domains import (
     DomainsHandler, DomainDetailsHandler, DomainViolationsPerDayHandler,
-    DomainReviewsHandler, DomainsChangeStatusHandler
+    DomainReviewsHandler, DomainsChangeStatusHandler, DomainsFullDataHandler,
+    DomainPageCountHandler, DomainReviewCountHandler, DomainViolationCountHandler,
+    DomainErrorPercentageHandler, DomainResponseTimeAvgHandler, DomainGroupedViolationsHandler,
+    DomainTopCategoryViolationsHandler
 )
 from holmes.handlers.search import (
     SearchHandler
@@ -30,8 +36,8 @@ from holmes.handlers.search import (
 from holmes.handlers.settings import (
     TaxHandler
 )
-from holmes.handlers.request import RequestDomainHandler
-from holmes.handlers.users import UserLoginHandler
+from holmes.handlers.request import RequestDomainHandler, LastRequestsHandler
+from holmes.handlers.limiter import LimiterHandler
 
 from holmes.handlers.bus import EventBusHandler
 from holmes.event_bus import EventBus, NoOpEventBus
@@ -76,16 +82,27 @@ class HolmesApiServer(Server):
             (r'/search/?', SearchHandler),
             (r'/page/?', PageHandler),
             (r'/domains/?', DomainsHandler),
+            (r'/domains-details/?', DomainsFullDataHandler),
             (r'/domains/([^/]+)/?', DomainDetailsHandler),
+            (r'/domains/([^/]+)/page-count/?', DomainPageCountHandler),
+            (r'/domains/([^/]+)/review-count/?', DomainReviewCountHandler),
+            (r'/domains/([^/]+)/violation-count/?', DomainViolationCountHandler),
+            (r'/domains/([^/]+)/error-percentage/?', DomainErrorPercentageHandler),
+            (r'/domains/([^/]+)/response-time-avg/?', DomainResponseTimeAvgHandler),
             (r'/domains/([^/]+)/violations-per-day/?', DomainViolationsPerDayHandler),
+            (r'/domains/([^/]+)/violations/?', DomainGroupedViolationsHandler),
+            (r'/domains/([^/]+)/violations/([0-9]+)/?', DomainTopCategoryViolationsHandler),
             (r'/domains/([^/]+)/reviews/?', DomainReviewsHandler),
             (r'/domains/([^/]+)/change-status/?', DomainsChangeStatusHandler),
             (r'/domains/([^/]+)/requests/([0-9]*)/?', RequestDomainHandler),
             (r'/events/?', EventBusHandler),
             (r'/violations/?', ViolationsHandler),
-            (r'/violation/([a-z0-9\.]*)/?', ViolationHandler),
+            (r'/violation/([_a-z0-9\.]*)/?', ViolationHandler),
+            (r'/violation/([_a-z0-9\.]*)/domains/?', ViolationDomainsHandler),
             (r'/tax/?', TaxHandler),
-            (r'/user/login/([^/]+)/?', UserLoginHandler),
+            (r'/limiters/?', LimiterHandler),
+            (r'/next-jobs/?', NextJobHandler),
+            (r'/last-requests/?', LastRequestsHandler),
         ]
 
         return tuple(handlers)
@@ -103,8 +120,8 @@ class HolmesApiServer(Server):
             self.application.db = self.application.get_sqlalchemy_session()
 
         if self.debug:
-            import sqltap
-            sqltap.start()
+            from sqltap import sqltap
+            self.sqltap = sqltap.start()
 
         self.application.facters = self._load_facters()
         self.application.validators = self._load_validators()
@@ -129,6 +146,20 @@ class HolmesApiServer(Server):
 
         self.application.cache = Cache(self.application)
 
+        self.configure_material_girl()
+
+    def configure_material_girl(self):
+        from holmes.material import configure_materials
+
+        host = self.config.get('MATERIAL_GIRL_REDISHOST')
+        port = self.config.get('MATERIAL_GIRL_REDISPORT')
+
+        self.redis_material = redis.StrictRedis(host=host, port=port, db=0)
+
+        self.application.girl = Materializer(storage=RedisStorage(redis=self.redis_material))
+
+        configure_materials(self.application.girl, self.application.db, self.config)
+
     def _insert_key_category(self, key, name):
         category = KeysCategory.get_or_create(self.application.db, name)
         self.application.db.add(category)
@@ -162,9 +193,10 @@ class HolmesApiServer(Server):
     def before_end(self, io_loop):
         self.application.db.remove()
 
-        if self.debug:
-            import sqltap
-            statistics = sqltap.collect()
+        if self.debug and getattr(self, 'sqltap', None) is not None:
+            from sqltap import sqltap
+
+            statistics = self.sqltap.collect()
             sqltap.report(statistics, "report.html")
 
     def connect_pub_sub(self, io_loop):
